@@ -82,14 +82,16 @@ hop_index2 <- function(.x, .y, .i, .starts, .stops, .f, ...) {
 
 #' @rdname hop_index2
 #' @export
-hop_index2_vec <- function(.x,
-                           .y,
-                           .i,
-                           .starts,
-                           .stops,
-                           .f,
-                           ...,
-                           .ptype = NULL) {
+hop_index2_vec <- function(
+  .x,
+  .y,
+  .i,
+  .starts,
+  .stops,
+  .f,
+  ...,
+  .ptype = NULL
+) {
   out <- hop_index2_impl(
     .x,
     .y,
@@ -108,16 +110,25 @@ hop_index2_vec <- function(.x,
 
 # ------------------------------------------------------------------------------
 
-hop_index2_impl <- function(.x, .y, .i, .starts, .stops, .f, ..., .ptype, .constrain, .atomic) {
-  vec_assert(.x)
-  vec_assert(.y)
+hop_index2_impl <- function(
+  .x,
+  .y,
+  .i,
+  .starts,
+  .stops,
+  .f,
+  ...,
+  .ptype,
+  .constrain,
+  .atomic,
+  .slider_error_call = caller_env()
+) {
+  vec_assert(.x, call = .slider_error_call)
+  vec_assert(.y, call = .slider_error_call)
 
-  # TODO - Do more efficiently internally by reusing rather than recycling
-  # https://github.com/tidyverse/purrr/blob/e4d553989e3d18692ebeeedb334b6223ae9ea294/src/map.c#L129
-  # But use `vec_size_common()` to check sizes and get `.size`
-  args <- vec_recycle_common(.x, .y)
+  args <- vec_recycle_common(.x = .x, .y = .y, .call = .slider_error_call)
 
-  .f <- as_function(.f)
+  .f <- as_function(.f, call = .slider_error_call)
 
   f_call <- expr(.f(.x, .y, ...))
 
@@ -133,6 +144,7 @@ hop_index2_impl <- function(.x, .y, .i, .starts, .stops, .f, ..., .ptype, .const
     constrain = .constrain,
     atomic = .atomic,
     env = environment(),
-    type = type
+    type = type,
+    slider_error_call = .slider_error_call
   )
 }
