@@ -98,91 +98,105 @@
 #'
 #' # Skip every other calculation
 #' slide_sum(x, before = 2, step = 2)
-slide_sum <- function(x,
-                      ...,
-                      before = 0L,
-                      after = 0L,
-                      step = 1L,
-                      complete = FALSE,
-                      na_rm = FALSE) {
+slide_sum <- function(
+  x,
+  ...,
+  before = 0L,
+  after = 0L,
+  step = 1L,
+  complete = FALSE,
+  na_rm = FALSE
+) {
   check_dots_empty0(...)
   .Call(slider_sum, x, before, after, step, complete, na_rm)
 }
 
 #' @rdname summary-slide
 #' @export
-slide_prod <- function(x,
-                       ...,
-                       before = 0L,
-                       after = 0L,
-                       step = 1L,
-                       complete = FALSE,
-                       na_rm = FALSE) {
+slide_prod <- function(
+  x,
+  ...,
+  before = 0L,
+  after = 0L,
+  step = 1L,
+  complete = FALSE,
+  na_rm = FALSE
+) {
   check_dots_empty0(...)
   .Call(slider_prod, x, before, after, step, complete, na_rm)
 }
 
 #' @rdname summary-slide
 #' @export
-slide_mean <- function(x,
-                       ...,
-                       before = 0L,
-                       after = 0L,
-                       step = 1L,
-                       complete = FALSE,
-                       na_rm = FALSE) {
+slide_mean <- function(
+  x,
+  ...,
+  before = 0L,
+  after = 0L,
+  step = 1L,
+  complete = FALSE,
+  na_rm = FALSE
+) {
   check_dots_empty0(...)
   .Call(slider_mean, x, before, after, step, complete, na_rm)
 }
 
 #' @rdname summary-slide
 #' @export
-slide_min <- function(x,
-                      ...,
-                      before = 0L,
-                      after = 0L,
-                      step = 1L,
-                      complete = FALSE,
-                      na_rm = FALSE) {
+slide_min <- function(
+  x,
+  ...,
+  before = 0L,
+  after = 0L,
+  step = 1L,
+  complete = FALSE,
+  na_rm = FALSE
+) {
   check_dots_empty0(...)
   .Call(slider_min, x, before, after, step, complete, na_rm)
 }
 
 #' @rdname summary-slide
 #' @export
-slide_max <- function(x,
-                      ...,
-                      before = 0L,
-                      after = 0L,
-                      step = 1L,
-                      complete = FALSE,
-                      na_rm = FALSE) {
+slide_max <- function(
+  x,
+  ...,
+  before = 0L,
+  after = 0L,
+  step = 1L,
+  complete = FALSE,
+  na_rm = FALSE
+) {
   check_dots_empty0(...)
   .Call(slider_max, x, before, after, step, complete, na_rm)
 }
 
 #' @rdname summary-slide
 #' @export
-slide_all <- function(x,
-                      ...,
-                      before = 0L,
-                      after = 0L,
-                      step = 1L,
-                      complete = FALSE,
-                      na_rm = FALSE) {
+slide_all <- function(
+  x,
+  ...,
+  before = 0L,
+  after = 0L,
+  step = 1L,
+  complete = FALSE,
+  na_rm = FALSE
+) {
   check_dots_empty0(...)
   .Call(slider_all, x, before, after, step, complete, na_rm)
 }
 
 #' @rdname summary-slide
 #' @export
-slide_any <- function(x,
-                      ...,
-                      before = 0L,
-                      after = 0L,
-                      step = 1L,
-                      complete = FALSE,
-                      na_rm = FALSE) {
+slide_any <- function(
+  x,
+  ...,
+  before = 0L,
+  after = 0L,
+  step = 1L,
+  complete = FALSE,
+  na_rm = FALSE
+) {
   check_dots_empty0(...)
   .Call(slider_any, x, before, after, step, complete, na_rm)
 }
