@@ -5,15 +5,10 @@
 
 // Experimental non-public vctrs functions
 extern SEXP (*vec_cast)(SEXP, SEXP);
-extern SEXP (*vec_restore)(SEXP, SEXP);
-extern SEXP (*vec_proxy)(SEXP);
 extern SEXP (*vec_chop)(SEXP, SEXP);
-extern SEXP (*vec_proxy_assign)(SEXP, SEXP, SEXP);
 extern SEXP (*vec_slice_impl)(SEXP, SEXP);
 extern SEXP (*vec_names)(SEXP);
-extern SEXP (*vec_set_names)(SEXP, SEXP);
-extern SEXP (*vec_init)(SEXP, R_len_t);
 extern SEXP (*compact_seq)(R_len_t, R_len_t, bool);
-extern SEXP (*init_compact_seq)(int*, R_len_t, R_len_t, bool);
+extern void (*init_compact_seq)(int*, R_len_t, R_len_t, bool);
 
 #endif
