@@ -7,13 +7,11 @@ local_methods <- function(..., .frame = caller_env()) {
 }
 
 local_c_foobar <- function(frame = caller_env()) {
-  local_methods(.frame = frame,
-    c.slider_foobar = function(...) {
-      signal("", class = "slider_c_foobar")
-      xs <- list(...)
-      xs <- lapply(xs, unclass)
-      out <- vec_unchop(xs)
-      foobar(out)
-    }
-  )
+  local_methods(.frame = frame, c.slider_foobar = function(...) {
+    signal("", class = "slider_c_foobar")
+    xs <- list(...)
+    xs <- lapply(xs, unclass)
+    out <- list_unchop(xs)
+    foobar(out)
+  })
 }
