@@ -21,21 +21,44 @@ test_that("defaults work with `.i`", {
 })
 
 test_that(".x must be the same size as .i", {
-  expect_error(slide_index(1, 1:2, identity), class = "slider_error_index_incompatible_size")
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, 1:2, identity),
+      class = "slider_error_index_incompatible_size"
+    ))
+  })
 })
 
 test_that(".i must be ascending", {
-  expect_error(slide_index(1:2, 2:1, identity), class = "slider_error_index_must_be_ascending")
+  expect_snapshot({
+    (expect_error(
+      slide_index(1:2, 2:1, identity),
+      class = "slider_error_index_must_be_ascending"
+    ))
+  })
 })
 
 test_that("empty input returns a list, but after the index size check", {
   expect_equal(slide_index(integer(), integer(), ~.x), list())
-  expect_error(slide_index(integer(), 1, ~.x), class = "slider_error_index_incompatible_size")
+  expect_snapshot({
+    (expect_error(
+      slide_index(integer(), 1, ~.x),
+      class = "slider_error_index_incompatible_size"
+    ))
+  })
 })
 
 test_that(".i must not contain NA values", {
-  expect_error(slide_index(1:2, c(1, NA), identity), class = "slider_error_index_cannot_be_na")
-  expect_error(slide_index(1:2, c(NA, 1), identity), class = "slider_error_index_cannot_be_na")
+  expect_error(
+    slide_index(1:2, c(1, NA), identity),
+    class = "slider_error_index_cannot_be_na"
+  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1:2, c(NA, 1), identity),
+      class = "slider_error_index_cannot_be_na"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -97,17 +120,21 @@ test_that("using .before on an irregular date index works", {
 })
 
 test_that(".before must be size 1", {
-  expect_error(
-    slide_index(1, 1, identity, .before = c(1L, 2L)),
-    class = "vctrs_error_assert_size"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, 1, identity, .before = c(1L, 2L)),
+      class = "vctrs_error_assert_size"
+    ))
+  })
 })
 
 test_that("error if .before is NULL", {
-  expect_error(
-    slide_index(1, 1, identity, .before = NULL),
-    class = "vctrs_error_scalar_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, 1, identity, .before = NULL),
+      class = "vctrs_error_scalar_type"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -172,10 +199,9 @@ test_that("negative .before errors if its absolute value is past .after", {
   i <- new_date(c(0, 1, 2, 3))
   x <- i
 
-  expect_error(
-    slide_index(x, i, identity, .before = -1, .after = 0),
-    "the start of the range is after the end of the range at location[(]s[)]: 1, 2, 3, 4"
-  )
+  expect_snapshot(error = TRUE, {
+    slide_index(x, i, identity, .before = -1, .after = 0)
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -288,7 +314,13 @@ test_that("can use negative Durations with POSIXct", {
   x <- seq_along(i)
 
   expect_equal(
-    slide_index(x, i, identity, .before = -lubridate::ddays(1), .after = lubridate::ddays(1)),
+    slide_index(
+      x,
+      i,
+      identity,
+      .before = -lubridate::ddays(1),
+      .after = lubridate::ddays(1)
+    ),
     list(
       2L,
       3L,
@@ -298,7 +330,13 @@ test_that("can use negative Durations with POSIXct", {
   )
 
   expect_equal(
-    slide_index(x, i, identity, .before = -lubridate::ddays(1), .after = lubridate::ddays(2)),
+    slide_index(
+      x,
+      i,
+      identity,
+      .before = -lubridate::ddays(1),
+      .after = lubridate::ddays(2)
+    ),
     list(
       2:3,
       3:4,
@@ -312,10 +350,9 @@ test_that("errors if negative .before Duration is further than .after", {
   i <- lubridate::as_datetime(new_date(c(0, 1, 2, 3)))
   x <- seq_along(i)
 
-  expect_error(
-    slide_index(x, i, identity, .before = -lubridate::ddays(1), .after = 0),
-    "the start of the range is after the end of the range at location[(]s[)]: 1, 2, 3, 4"
-  )
+  expect_snapshot(error = TRUE, {
+    slide_index(x, i, identity, .before = -lubridate::ddays(1), .after = 0)
+  })
 })
 
 test_that("can use millisecond Durations with POSIXct", {
@@ -444,10 +481,12 @@ test_that("can generally use (tricky!) month Periods with Dates", {
   # General solution is to use ~ .x %m-% months(1) instead
   i <- as.Date("2019-03-30") + months(0:3)
 
-  expect_error(
-    slide_index(x, i, identity, .before = months(1)),
-    class = "slider_error_generated_endpoints_cannot_be_na"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(x, i, identity, .before = months(1)),
+      class = "slider_error_generated_endpoints_cannot_be_na"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -484,40 +523,6 @@ test_that("can use year Durations/Periods with Dates and leap years", {
   )
 })
 
-# ------------------------------------------------------------------------------
-# .before - nanotime
-
-# TODO - vec_compare() can't handle nanotime objects
-# could provide a vec_proxy_compare
-# vctrs:::vec_proxy_compare.integer64(nanotime::nanotime(c(1, 2, 3, 6, 4)))
-
-# test_that("can use nanotime resolution", {
-#   i <- nanotime::nanotime(1:5)
-#   x <- seq_along(i)
-#
-#   expect_equal(
-#     slide_index(x, i, identity, .before = 1L),
-#     list(
-#       1L,
-#       1:2,
-#       2:3,
-#       3:4,
-#       4:5
-#     )
-#   )
-#
-#   expect_equal(
-#     slide_index(x, i, identity, .before = 2L),
-#     list(
-#       1L,
-#       1:2,
-#       1:3,
-#       2:4,
-#       3:5
-#     )
-#   )
-# })
-
 # ------------------------------------------------------------------------------
 # .after - integer
 
@@ -577,17 +582,21 @@ test_that("using .after on an irregular date index works", {
 })
 
 test_that(".after must be size 1", {
-  expect_error(
-    slide_index(1, 1, identity, .after = c(1L, 2L)),
-    class = "vctrs_error_assert_size"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, 1, identity, .after = c(1L, 2L)),
+      class = "vctrs_error_assert_size"
+    ))
+  })
 })
 
 test_that("error if .after is NULL", {
-  expect_error(
-    slide_index(1, 1, identity, .after = NULL),
-    class = "vctrs_error_scalar_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, 1, identity, .after = NULL),
+      class = "vctrs_error_scalar_type"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -668,10 +677,9 @@ test_that("negative .after errors if its absolute value is past .before", {
   i <- new_date(c(0, 1, 2, 3))
   x <- i
 
-  expect_error(
-    slide_index(x, i, identity, .after = -1, .before = 0),
-    "the start of the range is after the end of the range at location[(]s[)]: 1, 2, 3, 4"
-  )
+  expect_snapshot(error = TRUE, {
+    slide_index(x, i, identity, .after = -1, .before = 0)
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -805,13 +813,14 @@ test_that("can generally use (tricky!) month Periods with Dates", {
   # General solution is to use ~ .x %m-% months(1) instead
   i <- as.Date("2019-01-30") + months(-3:0)
 
-  expect_error(
-    slide_index(x, i, identity, .after = months(1)),
-    class = "slider_error_generated_endpoints_cannot_be_na"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(x, i, identity, .after = months(1)),
+      class = "slider_error_generated_endpoints_cannot_be_na"
+    ))
+  })
 })
 
-
 # ------------------------------------------------------------------------------
 # .after - lubridate - Leap Years / DST
 
@@ -847,6 +856,54 @@ test_that("can use Durations/Periods to handle daylight savings differently", {
   )
 })
 
+# ------------------------------------------------------------------------------
+# .before / .after - non-vctrs types
+
+test_that(".i/.before/.after can be non-vctrs types (#182)", {
+  local_c_foobar()
+
+  i <- foobar(1:4)
+  x <- seq_along(i)
+
+  expect_identical(
+    slide_index(x, i, identity, .before = 2L),
+    list(
+      1L,
+      1:2,
+      1:3,
+      2:4
+    )
+  )
+  expect_identical(
+    slide_index(x, i, identity, .before = foobar(2L)),
+    list(
+      1L,
+      1:2,
+      1:3,
+      2:4
+    )
+  )
+
+  expect_identical(
+    slide_index(x, i, identity, .after = 2L),
+    list(
+      1:3,
+      2:4,
+      3:4,
+      4L
+    )
+  )
+  expect_identical(
+    slide_index(x, i, identity, .after = foobar(2L)),
+    list(
+      1:3,
+      2:4,
+      3:4,
+      4L
+    )
+  )
+})
+
 # ------------------------------------------------------------------------------
 # .before / .after - function
 
@@ -858,7 +915,7 @@ test_that(".before/.after - can use a function", {
     slide_index(x, x, identity, .before = 2)
   )
   expect_identical(
-    slide_index(x, x, identity, .before = ~.x - 2),
+    slide_index(x, x, identity, .before = ~ .x - 2),
     slide_index(x, x, identity, .before = 2)
   )
   expect_identical(
@@ -866,7 +923,7 @@ test_that(".before/.after - can use a function", {
     slide_index(x, x, identity, .after = 2)
   )
   expect_identical(
-    slide_index(x, x, identity, .after = ~.x + 2),
+    slide_index(x, x, identity, .after = ~ .x + 2),
     slide_index(x, x, identity, .after = 2)
   )
 })
@@ -875,11 +932,21 @@ test_that(".before/.after - using a function can help with lubridate `+ months(1
   x <- as.Date(c("2019-01-31", "2019-02-28", "2019-03-31"))
 
   expect_identical(
-    slide_index(x, x, identity, .before = ~lubridate::add_with_rollback(.x, months(-1))),
+    slide_index(
+      x,
+      x,
+      identity,
+      .before = ~ lubridate::add_with_rollback(.x, months(-1))
+    ),
     list(x[1], x[1:2], x[2:3])
   )
   expect_identical(
-    slide_index(x, x, identity, .after = ~lubridate::add_with_rollback(.x, months(1))),
+    slide_index(
+      x,
+      x,
+      identity,
+      .after = ~ lubridate::add_with_rollback(.x, months(1))
+    ),
     list(x[1:2], x[2], x[3])
   )
 })
@@ -887,52 +954,38 @@ test_that(".before/.after - using a function can help with lubridate `+ months(1
 test_that(".before/.after - generated endpoints must be in weakly ascending order", {
   x <- c(1, 2)
 
-  expect_error(
-    slide_index(x, x, identity, .before = ~.x - c(2, 4)),
-    class = "slider_error_generated_endpoints_must_be_ascending"
-  )
-  expect_snapshot_error(
-    slide_index(x, x, identity, .before = ~.x - c(2, 4))
-  )
-  expect_error(
-    slide_index(x, x, identity, .after = ~.x + c(4, 2)),
-    class = "slider_error_generated_endpoints_must_be_ascending"
-  )
-  expect_snapshot_error(
-    slide_index(x, x, identity, .after = ~.x + c(4, 2))
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(x, x, identity, .before = ~ .x - c(2, 4)),
+      class = "slider_error_generated_endpoints_must_be_ascending"
+    ))
+    (expect_error(
+      slide_index(x, x, identity, .after = ~ .x + c(4, 2)),
+      class = "slider_error_generated_endpoints_must_be_ascending"
+    ))
+  })
 })
 
 test_that(".before/.after - generated endpoints must maintain .before <= .after ordering", {
-  expect_error(
-    slide_index(1:2, 1:2, identity, .before = ~.x + 1, .after = 0),
-    "start of the range is after the end of the range"
-  )
-  expect_snapshot_error(
-    slide_index(1:2, 1:2, identity, .before = ~.x + 1, .after = 0)
-  )
-  expect_error(
-    slide_index(1:2, 1:2, identity, .before = 0, .after = ~.x - 1),
-    "start of the range is after the end of the range"
-  )
-  expect_snapshot_error(
-    slide_index(1:2, 1:2, identity, .before = 0, .after = ~.x - 1)
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1:2, 1:2, identity, .before = ~ .x + 1, .after = 0)
+    ))
+    (expect_error(
+      slide_index(1:2, 1:2, identity, .before = 0, .after = ~ .x - 1)
+    ))
+  })
 })
 
 test_that(".before/.after - generated endpoints can't be NA", {
-  expect_error(
-    slide_index(1:2, 1:2, identity, .before = ~rep(NA_integer_, length(.x)))
-  )
-  expect_snapshot_error(
-    slide_index(1:2, 1:2, identity, .before = ~rep(NA_integer_, length(.x)))
-  )
-  expect_error(
-    slide_index(1:2, 1:2, identity, .after = ~rep(NA_integer_, length(.x)))
-  )
-  expect_snapshot_error(
-    slide_index(1:2, 1:2, identity, .after = ~rep(NA_integer_, length(.x)))
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1:2, 1:2, identity, .before = ~ rep(NA_integer_, length(.x)))
+    ))
+    (expect_error(
+      slide_index(1:2, 1:2, identity, .after = ~ rep(NA_integer_, length(.x)))
+    ))
+  })
 })
 
 test_that(".before/.after - generated endpoints shouldn't rely on original `.i` length", {
@@ -940,27 +993,24 @@ test_that(".before/.after - generated endpoints shouldn't rely on original `.i`
   x <- c(1, 1)
   adjust <- c(2, 3)
 
-  expect_error(
-    slide_index(x, x, identity, .before = ~.x - adjust),
-    class = "slider_error_generated_endpoints_incompatible_size"
-  )
-  expect_snapshot_error(
-    slide_index(x, x, identity, .before = ~.x - adjust)
-  )
-  expect_error(
-    slide_index(x, x, identity, .after = ~.x + adjust),
-    class = "slider_error_generated_endpoints_incompatible_size"
-  )
-  expect_snapshot_error(
-    slide_index(x, x, identity, .after = ~.x + adjust)
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(x, x, identity, .before = ~ .x - adjust),
+      class = "slider_error_generated_endpoints_incompatible_size"
+    ))
+    (expect_error(
+      slide_index(x, x, identity, .after = ~ .x + adjust),
+      class = "slider_error_generated_endpoints_incompatible_size"
+    ))
+  })
 })
 
 test_that(".before/.after - function must have 1 argument", {
+  # Base R errors
   expect_error(slide_index(1, 1, identity, .before = function(x, y) x + y))
-  expect_error(slide_index(1, 1, identity, .before = ~.x + .y))
+  expect_error(slide_index(1, 1, identity, .before = ~ .x + .y))
   expect_error(slide_index(1, 1, identity, .after = function(x, y) x + y))
-  expect_error(slide_index(1, 1, identity, .after = ~.x + .y))
+  expect_error(slide_index(1, 1, identity, .after = ~ .x + .y))
 })
 
 # ------------------------------------------------------------------------------
@@ -1033,10 +1083,12 @@ test_that(".complete only ensures that there is at least 1 value before that cou
 })
 
 test_that("cannot use an invalid .complete value", {
-  expect_error(
-    slide_index(1, 1, identity, .complete = "hi"),
-    class = "vctrs_error_incompatible_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, 1, identity, .complete = "hi"),
+      class = "vctrs_error_incompatible_type"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -1143,7 +1195,7 @@ test_that("can be doubly unbounded", {
 
 test_that("slide_index() doesn't require `size = 1`", {
   expect_equal(
-    slide_index(1:2, 1:2, ~c(.x, 1)),
+    slide_index(1:2, 1:2, ~ c(.x, 1)),
     list(
       c(1L, 1L),
       c(2L, 1L)
@@ -1153,7 +1205,15 @@ test_that("slide_index() doesn't require `size = 1`", {
 
 test_that("`slide_index()` doesn't require a common inner type", {
   expect_equal(
-    slide_index(1:2, 1:2, ~if (.x == 1L) {1} else {"hi"}),
+    slide_index(
+      1:2,
+      1:2,
+      ~ if (.x == 1L) {
+        1
+      } else {
+        "hi"
+      }
+    ),
     list(1, "hi")
   )
 })
@@ -1193,19 +1253,19 @@ test_that("names are retained on inner sliced object", {
   x <- set_names(1:5, names)
   i <- vec_seq_along(x)
   exp <- set_names(as.list(names), names)
-  expect_equal(slide_index(x, i, ~names(.x)), exp)
+  expect_equal(slide_index(x, i, ~ names(.x)), exp)
 
   names <- letters[1:5]
   x <- data.frame(x = 1:5, row.names = names)
   i <- vec_seq_along(x)
   expect <- set_names(as.list(names), names)
-  expect_equal(slide_index(x, i, ~rownames(.x)), expect)
+  expect_equal(slide_index(x, i, ~ rownames(.x)), expect)
 
   names <- c("r1", "r2")
   x <- array(1:4, c(2, 2), dimnames = list(names, c("c1", "c2")))
   i <- vec_seq_along(x)
   exp <- set_names(as.list(names), names)
-  expect_equal(slide_index(x, i, ~rownames(.x)), exp)
+  expect_equal(slide_index(x, i, ~ rownames(.x)), exp)
 })
 
 # ------------------------------------------------------------------------------
@@ -1227,19 +1287,23 @@ test_that("can use a data frame index", {
 test_that("`.i - .before` must be castable to `.i`", {
   i <- 1L
 
-  expect_error(
-    slide_index(1, i, identity, .before = 1.5),
-    class = "vctrs_error_cast_lossy"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, i, identity, .before = 1.5),
+      class = "vctrs_error_cast_lossy"
+    ))
+  })
 })
 
 test_that("`.i + .after` must be castable to `.i`", {
   i <- 1L
 
-  expect_error(
-    slide_index(1, i, identity, .after = 1.5),
-    class = "vctrs_error_cast_lossy"
-  )
+  expect_snapshot({
+    (expect_error(
+      slide_index(1, i, identity, .after = 1.5),
+      class = "vctrs_error_cast_lossy"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
@@ -1280,7 +1344,13 @@ test_that("repeated date index values are grouped with the same values", {
 
 test_that("can have an irregular index where the window is completely within two index values", {
   expect_equal(
-    slide_index(1:7, c(10, 11, 13, 17, 18, 19, 20), ~.x, .before = 3, .after = -2),
+    slide_index(
+      1:7,
+      c(10, 11, 13, 17, 18, 19, 20),
+      ~.x,
+      .before = 3,
+      .after = -2
+    ),
     list(
       integer(),
       integer(),
@@ -1315,7 +1385,7 @@ test_that("indexing by vec_seq_along(.x) is the same as slide()", {
 test_that("lambdas are equivalent to functions (#10)", {
   expect_equal(
     slide_index(1:10, 1:10, sum, .before = 3),
-    slide_index(1:10, 1:10, ~sum(.x), .before = 3)
+    slide_index(1:10, 1:10, ~ sum(.x), .before = 3)
   )
 })
 
@@ -1331,14 +1401,32 @@ test_that("stress test that we don't stack overflow (#34)", {
   expect_error(slide_index(1:1e6, 1:1e6, ~.x), NA)
 })
 
-test_that(paste0(
-            "proof that the `stops_pos < starts_pos` check is required for ",
-            "cases where we have an irregular series and ",
-            "the window is completely between values"
-          ), {
+test_that(
+  paste0(
+    "proof that the `stops_pos < starts_pos` check is required for ",
+    "cases where we have an irregular series and ",
+    "the window is completely between values"
+  ),
+  {
+    expect_equal(
+      slide_index(1:3, c(1, 3, 4), identity, .before = -1, .after = 1),
+      list(integer(), 3, integer())
+    )
+  }
+)
 
-  expect_equal(
-    slide_index(1:3, c(1, 3, 4), identity, .before = -1, .after = 1),
-    list(integer(), 3, integer())
-  )
+test_that("`error_call` and `.error_call` args aren't swallowed", {
+  fn <- function(x, error_call) {
+    abort("hi", call = error_call)
+  }
+  fn_dot <- function(x, .error_call) {
+    abort("hi", call = .error_call)
+  }
+
+  expect_snapshot(error = TRUE, {
+    slide_index(1, 1, fn, error_call = call("foo"))
+  })
+  expect_snapshot(error = TRUE, {
+    slide_index(1, 1, fn_dot, .error_call = call("foo"))
+  })
 })
